@@ -122,7 +122,7 @@ class ProcessManager:
                 if out is None:
                     sock.sendall(const.MSG_CODE+b"Error: Couldn't find process '" + name.encode() + b"'")
                 else:
-                    sock.sendall(const.DATA_CODE+'\n'.join(out).encode())
+                    sock.sendall(const.DATA_CODE+out)
             else:
                 sock.sendall(const.MSG_CODE+b"Error: Invalid number of arguments")
         except Exception:
@@ -139,7 +139,7 @@ class ProcessManager:
                 if err is None:
                     sock.sendall(const.MSG_CODE+b"Error: Couldn't find process '" + name.encode() + b"'")
                 else:
-                    sock.sendall(const.DATA_CODE+'\n'.join(err).encode())
+                    sock.sendall(const.DATA_CODE+err)
             else:
                 sock.sendall(const.MSG_CODE+b"Error: Invalid number of arguments")
         except Exception:
@@ -268,6 +268,15 @@ class ProcessManager:
         try:
             if len(command) == 5:
                 name, cmd, log_cpu, log_freq = command[1:]
+                if len(name) > 16:
+                    sock.sendall(const.MSG_CODE+b"Error: Name can't be over 16 characters long")
+                    return
+                if not name.isidentifier():
+                    sock.sendall(const.MSG_CODE+b"Error: Invalid name")
+                    return
+                if not cmd.isprintable():
+                    sock.sendall(const.MSG_CODE+b"Error: Invalid command")
+                    return
                 process = Process(name, cmd)
                 if self.add_process(process, sbool(log_cpu), sbool(log_freq)):
                     sock.sendall(const.MSG_CODE+b"Successfully added process '" + name.encode() + b"'")
